@@ -46,8 +46,6 @@
 #include <dataobj.h>    /* data object definitions and handler */
 #include <headers.h>    /* header definitions and handler */
 
-#include <R_ext/PrtUtil.h>
-
 
 /* OS check for printing %llu and %lli*/
 //#ifdef __unix__
@@ -194,9 +192,9 @@ DOBJ *asspFOpen(char *filePath, int mode, DOBJ *doPtr)
       	  freeDObj(dop);
       	} else if(CLEAR){
       	  clearDObj(dop);
-      	  setAsspMsg(AEF_ERR_OPEN, filePath);
-      	  return(NULL);
       	}
+      	setAsspMsg(AEF_ERR_OPEN, filePath);
+      	return(NULL);
       }
       err = getHeader(dop);
       if(err < 0) {
